# scientistmetrics

## About scientistmetrics

**scientistmetrics** is a `Python` package for calculating correlation amongst categorical variables.

## Why scientistmetrics?

The function provides the option for computing one of six measures of association between two nominal variables from the data given in a 2d contingency table: 
* Pearson's chi-squared test : https://en.wikipedia.org/wiki/Pearson%27s_chi-squared_test
* Phi coefficient : https://en.wikipedia.org/wiki/Phi_coefficient
* G-test: https://en.wikipedia.org/wiki/G-test
* Cramer's V : https://en.wikipedia.org/wiki/Cramer's_V
* Tschuprow's T : https://en.wikipedia.org/wiki/Tschuprow's_T
* Pearson contingency coefficient : https://www.statisticshowto.com/contingency-coefficient/

Notebook is availabled.

## Installation

### Dependencies

scientistmetrics requires :

```
Python >=3.10
Numpy >=1.23.5
Pandas >=1.5.3
Plotnine >=0.10.1
Scipy >=1.10.1
```

## User installation

You can install scientistmetrics using `pip` :

```
pip install scientistmetrics
```

## Author

Duvérier DJIFACK ZEBAZE